/*
Gnome-shell extension for Liled
Copyright (C) 2012  Yannick Poirier

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
 */

const GObject = imports.gi.GObject;
const Gio = imports.gi.Gio;
const Gtk = imports.gi.Gtk;
const ExtensionUtils = imports.misc.extensionUtils;

function init() {

}

const LiledPrefsWidget = new GObject.Class({
	Name: 'Liled.Prefs.Widget',
	GTypeName: 'LiledPrefsWidget',
	Extends: Gtk.Grid,

	_init: function(params) {
		this.parent(params);

		this._settings = this._getSettings();
		let vbox = new Gtk.Box({ orientation: Gtk.Orientation.VERTICAL, margin: 20, margin_top: 10  });

		vbox.add( this._addTextBox('Liled base url', 'url', true ));
		vbox.add( this._addTextBox('Username', 'username', true ));
		vbox.add( this._addTextBox('Password', 'password', false ));
		vbox.add( this._addIntBox('Refresh (in s)', 'refresh' ));
		this.attach(vbox, 0, 0, 1, 1);    	
	},
	_addTextBox: function( label_name, setting_name, visibility ) {
		let entry = new Gtk.Entry();
		entry.set_visibility(visibility);
		this._settings.bind(setting_name, entry, "text", Gio.SettingsBindFlags.DEFAULT);
		return this._addBox(label_name, setting_name, entry);
	},
	_addIntBox: function( label_name, setting_name ) {
		let entry = new Gtk.SpinButton();
		entry.set_range(10, 3600);
		entry.set_increments(10, 10);
		this._settings.bind(setting_name, entry, "value", Gio.SettingsBindFlags.DEFAULT);
		return this._addBox(label_name, setting_name, entry);
	},
	_addBox: function( label_name, setting_name, box ) {
		let hbox = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL  });
		let label = new Gtk.Label({ label: label_name, xalign: 0, margin_right:20  });

		hbox.pack_start(label, true, true, 0);
		hbox.add( box );
		return hbox;
	},
	_getSettings: function () {
		let schema_id = "org.gnome.shell.extensions.liled";
		let schema_path = ExtensionUtils.getCurrentExtension().path + "/schemas";
		let schema_source = Gio.SettingsSchemaSource.new_from_directory(schema_path,
				Gio.SettingsSchemaSource.get_default(),
				false);
		if (!schema_source) {
			throw new Error("Local schema directory for " + schema_id + " is missing");
		}
		let schema = schema_source.lookup(schema_id, true);
		if (!schema) {
			throw new Error("Schema " + schema_id + " is missing.  Has glib-compile-schemas been called for it?");
		}
		return new Gio.Settings({settings_schema: schema});
	}
});

function buildPrefsWidget() {
	let widget = new LiledPrefsWidget();
	widget.show_all();
	return widget;
}
